==> imuikit-1.0.6.20180206T-sources.jar: com/xdja/im/base/di/module/RepositoryModule.java <==
package com.xdja.im.base.di.module;

import com.xdja.im.base.di.scope.UserScope;
import com.xdja.im.core.repository.impl.ChatListCallBackImpl;
import com.xdja.im.core.repository.impl.SecurityImpl;
import com.xdja.im.core.repository.impl.UserOperateImpl;
import com.xdja.im.core.repository.impl.im.IMProxyCallBackImpl;
import com.xdja.im.core.repository.impl.im.IMProxyImpl;
import com.xdja.im.core.repository.impl.im.IMSDKCallBack;
import com.xdja.im.core.repository.interf.ChatListCallBack;
import com.xdja.im.core.repository.interf.ProxyRepository;
import com.xdja.im.core.repository.interf.SecurityRepository;
import com.xdja.im.core.repository.interf.UserOperateRepository;
import com.xdja.im.core.repository.interf.im.IMProxyCallBack;
import com.xdja.imsdk.callback.CallbackFunction;
import com.xdja.imsdk.callback.IMFileInfoCallback;
import com.xdja.imsdk.callback.IMMessageCallback;
import com.xdja.imsdk.callback.IMSecurityCallback;
import com.xdja.imsdk.callback.IMSessionCallback;

import dagger.Module;
import dagger.Provides;

/**
 * @Package: com.xdja.im.base.di.module
 * @Author: xdjaxa
 * @Creation: 2017-04-11 15:57
 * @Version V1.0
 * @Description:功能性模块注入提供者
 */
@Module
public class RepositoryModule {

    @UserScope
    @Provides
    ProxyRepository provideImProxyRepository(IMProxyImpl imProxyRepository) {
        return imProxyRepository;
    }

    @UserScope
    @Provides
    ChatListCallBack provideChatListCallBack(ChatListCallBackImpl chatListCallBack) {
        return chatListCallBack;
    }

    @UserScope
    @Provides
    SecurityRepository provideSecurityRepository(SecurityImpl securityRepository) {
        return securityRepository;
    }

    @UserScope
    @Provides
    UserOperateRepository provideUserOperateRepository(UserOperateImpl userOperateRepository) {
        return userOperateRepository;
    }

    @UserScope
    @Provides
    IMProxyCallBack provideIMProxyCallBack(IMProxyCallBackImpl callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    CallbackFunction provideCallbackFunction(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMFileInfoCallback provideIMFileInfoCallback(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMSessionCallback provideIMSessionCallback(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMMessageCallback provideIMMessageCallback(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMSecurityCallback provideIMSecurityCallback(IMSDKCallBack callback) {
        return callback;
    }
}

==> imuikit-1.0.9.20180609T-sources.jar: com/xdja/im/base/di/module/RepositoryModule.java <==
package com.xdja.im.base.di.module;

import com.xdja.im.base.di.scope.UserScope;
import com.xdja.im.core.repository.impl.ChatListCallBackImpl;
import com.xdja.im.core.repository.impl.SecurityImpl;
import com.xdja.im.core.repository.impl.UserOperateImpl;
import com.xdja.im.core.repository.impl.im.IMProxyCallBackImpl;
import com.xdja.im.core.repository.impl.im.IMProxyImpl;
import com.xdja.im.core.repository.impl.im.IMSDKCallBack;
import com.xdja.im.core.repository.interf.ChatListCallBack;
import com.xdja.im.core.repository.interf.ProxyRepository;
import com.xdja.im.core.repository.interf.SecurityRepository;
import com.xdja.im.core.repository.interf.UserOperateRepository;
import com.xdja.im.core.repository.interf.im.IMProxyCallBack;
import com.xdja.im.uikit.assistant.callback.MessageAssistantCallBack;
import com.xdja.im.uikit.assistant.callback.impl.MessageAssistantCallBackImpl;
import com.xdja.im.uikit.newui.callback.ChatDetailCallBack;
import com.xdja.im.uikit.newui.callbackimpl.ChatDetailCallBackImpl;
import com.xdja.imsdk.callback.CallbackFunction;
import com.xdja.imsdk.callback.IMFileInfoCallback;
import com.xdja.imsdk.callback.IMMessageCallback;
import com.xdja.imsdk.callback.IMSecurityCallback;
import com.xdja.imsdk.callback.IMSessionCallback;

import dagger.Module;
import dagger.Provides;

/**
 * @Package: com.xdja.im.base.di.module
 * @Author: xdjaxa
 * @Creation: 2017-04-11 15:57
 * @Version V1.0
 * @Description:功能性模块注入提供者
 */
@Module
public class RepositoryModule {

    @UserScope
    @Provides
    ProxyRepository provideImProxyRepository(IMProxyImpl imProxyRepository) {
        return imProxyRepository;
    }

    @UserScope
    @Provides
    ChatListCallBack provideChatListCallBack(ChatListCallBackImpl chatListCallBack) {
        return chatListCallBack;
    }

    @UserScope
    @Provides
    SecurityRepository provideSecurityRepository(SecurityImpl securityRepository) {
        return securityRepository;
    }

    @UserScope
    @Provides
    UserOperateRepository provideUserOperateRepository(UserOperateImpl userOperateRepository) {
        return userOperateRepository;
    }

    @UserScope
    @Provides
    IMProxyCallBack provideIMProxyCallBack(IMProxyCallBackImpl callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    CallbackFunction provideCallbackFunction(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMFileInfoCallback provideIMFileInfoCallback(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMSessionCallback provideIMSessionCallback(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMMessageCallback provideIMMessageCallback(IMSDKCallBack callBack) {
        return callBack;
    }

    @UserScope
    @Provides
    IMSecurityCallback provideIMSecurityCallback(IMSDKCallBack callback) {
        return callback;
    }

    @UserScope
    @Provides
    ChatDetailCallBack provideChatDetailCallBack(ChatDetailCallBackImpl callback) {
        return callback;
    }

    @UserScope
    @Provides
    MessageAssistantCallBack provideMessageAssistantCallBack(MessageAssistantCallBackImpl callback) {
        return callback;
    }
}
